@@ -1,5 +1,3 @@
-import asyncio
-
 import discord
 from discord.ext import commands
 
@@ -12,7 +10,9 @@ class MiscCommands(utils.Cog):
     @utils.checks.is_config_set('command_data', 'guild_invite')
     @commands.bot_has_permissions(send_messages=True)
     async def server(self, ctx:utils.Context):
-        """Gives the invite to the support server"""
+        """
+        Gives the invite to the support server.
+        """
 
         await ctx.send(f"<{self.bot.config['command_data']['guild_invite']}>")
 
@@ -20,7 +20,9 @@ class MiscCommands(utils.Cog):
     @utils.checks.is_config_set('command_data', 'donate_link')
     @commands.bot_has_permissions(send_messages=True)
     async def donate(self, ctx:utils.Context):
-        """Gives you the bot's creator's Patreon"""
+        """
+        Gives you the bot's creator's donate link.
+        """
 
         await ctx.send(f"<{self.bot.config['command_data']['donate_link']}>")
 
@@ -29,7 +31,9 @@ class MiscCommands(utils.Cog):
     @commands.bot_has_permissions(send_messages=True)
     @utils.checks.is_config_set('command_data', 'echo_command_enabled')
     async def echo(self, ctx:utils.Context, *, content:str):
-        """Echos the given content into the channel"""
+        """
+        Echos the given content into the channel.
+        """
 
         await ctx.send(content, allowed_mentions=discord.AllowedMentions(everyone=False, users=False, roles=False))
 
