@@ -1,5 +1,3 @@
-import re as regex
-
 from discord.ext import commands
 
 
@@ -9,15 +7,14 @@ class UserID(int):
     When used, this would provide the ID of the user.
     """
 
-    USER_ID_REGEX = regex.compile(r'([0-9]{15,21})')
-
     @classmethod
     async def convert(cls, ctx:commands.Context, value:str) -> int:
         """
         Converts the given value to a valid user ID.
         """
 
-        match = cls.USER_ID_REGEX.search(value)
+        commands.IDConverter
+        match = commands.IDConverter()._get_id_match(value)
         if match is not None:
             return int(match.group(1))
         raise commands.BadArgument()
