@@ -16,6 +16,8 @@ from discord.ext import commands
 from .custom_context import CustomContext
 from .database import DatabaseConnection
 from .redis import RedisConnection
+from .statsd import StatsdConnection
+from .analytics_http_client import AnalyticsBaseConnector
 from .. import all_packages as all_vfl_package_names
 
 
@@ -85,7 +87,7 @@ class CustomBot(commands.AutoShardedBot):
         # Run original
         super().__init__(
             command_prefix=get_prefix, activity=activity, status=status, case_insensitive=case_insensitive, intents=intents,
-            allowed_mentions=allowed_mentions, *args, **kwargs,
+            allowed_mentions=allowed_mentions, connector=kwargs.pop("connector", AnalyticsBaseConnector(self)), *args, **kwargs,
         )
 
         # Set up our default guild settings
@@ -106,6 +108,11 @@ class CustomBot(commands.AutoShardedBot):
         self.redis = RedisConnection
         self.redis.logger = self.logger.getChild('redis')
 
+        # Allow Statsd connections like this
+        self.stats = StatsdConnection
+        self.stats.config = self.config.get('statsd', {})
+        self.stats.logger = self.logger.getChild('statsd')
+
         # Store the startup method so I can see if it completed successfully
         self.startup_time = dt.now()
         self.startup_method = None
@@ -119,6 +126,17 @@ class CustomBot(commands.AutoShardedBot):
         Clears all the bot's caches and fills them from a DB read
         """
 
+        try:
+            await self._startup()
+        except Exception as e:
+            self.logger.error(e)
+            exit(1)
+
+    async def _startup(self):
+        """
+        Runs the actual db stuff so I can wrap it in a try
+        """
+
         # Remove caches
         self.logger.debug("Clearing caches")
         self.guild_settings.clear()
@@ -140,12 +158,25 @@ class CustomBot(commands.AutoShardedBot):
             for key, value in row.items():
                 self.guild_settings[row['guild_id']][key] = value
 
+        # Get default user settings
+        default_user_settings = await db("SELECT * FROM user_settings WHERE user_id=0")
+        if not default_user_settings:
+            default_user_settings = await db("INSERT INTO user_settings (user_id) VALUES (0) RETURNING *")
+        for i, o in default_user_settings[0].items():
+            self.DEFAULT_USER_SETTINGS.setdefault(i, o)
+
         # Get user settings
         data = await self._get_all_table_data(db, "user_settings")
         for row in data:
             for key, value in row.items():
                 self.user_settings[row['user_id']][key] = value
 
+        # Run the user-added startup methods
+        async def fake_cache_setup_method(db):
+            pass
+        for cog_name, cog in self.cogs.items():
+            self.loop.create_task(getattr(cog, "cache_setup", fake_cache_setup_method)(db))
+
         # Wait for the bot to cache users before continuing
         self.logger.debug("Waiting until ready before completing startup method.")
         await self.wait_until_ready()
@@ -267,6 +298,62 @@ class CustomBot(commands.AutoShardedBot):
         except Exception:
             return  # Ah well
 
+    async def create_message_log(self, messages:typing.List[discord.Message]) -> str:
+        """
+        Args:
+            messages (typing.List[discord.Message]): The messages you want to create into a log.
+
+        Returns:
+            str: The HTML for a log file.
+        """
+
+        # Let's flatten the messages if we need to
+        if isinstance(messages, discord.iterators.HistoryIterator):
+            messages = await messages.flatten()
+
+        # Create the data we're gonna send
+        data = {
+            "channel_name": messages[0].channel.name,
+            "category_name": messages[0].channel.category.name,
+            "guild_name": messages[0].guild.name,
+            "guild_icon_url": str(messages[0].guild.icon_url),
+        }
+        data_authors = {}
+        data_messages = []
+
+        # Get the data from the server
+        for message in messages:
+            for user in message.mentions + [message.author]:
+                data_authors[user.id] = {
+                    "username": user.name,
+                    "discriminator": user.discriminator,
+                    "avatar_url": str(user.avatar_url),
+                    "bot": user.bot,
+                    "display_name": user.display_name,
+                    "color": user.colour.value,
+                }
+            message_data = {
+                "id": message.id,
+                "content": message.content,
+                "author_id": message.author.id,
+                "timestamp": int(message.created_at.timestamp()),
+                "attachments": [str(i.url) for i in message.attachments],
+                # "embeds": [i.to_dict() for i in message.embeds],
+            }
+            embeds = []
+            for i in message.embeds:
+                embed_data = i.to_dict()
+                if i.timestamp:
+                    embed_data.update({'timestamp': i.timestamp.timestamp()})
+                embeds.append(embed_data)
+            message_data.update({'embeds': embeds})
+            data_messages.append(message_data)
+
+        # Send data to the API
+        data.update({"users": data_authors, "messages": data_messages[::-1]})
+        async with self.session.post("https://voxelfox.co.uk/discord/chatlog", json=data) as r:
+            return await r.text()
+
     @property
     def owner_ids(self) -> list:
         return self.config['owners']
@@ -413,3 +500,17 @@ class CustomBot(commands.AutoShardedBot):
         self.logger.info("Setting activity to default")
         await self.set_default_presence()
         self.logger.info('Bot loaded.')
+
+    async def invoke(self, ctx):
+        if ctx.command is None:
+            return await super().invoke(ctx)
+        command_stats_name = ctx.command.qualified_name.replace(' ', ':')
+        command_stats_tags = {
+            "command_name": command_stats_name,
+            # "guild_id": "DMs" if ctx.guild is None else ctx.guild.id,
+            # "user_id": ctx.author.id,
+            # "channel_id": "DMs" if ctx.guild is None else ctx.channel.id,
+        }
+        async with self.stats() as stats:
+            stats.increment("discord.bot.commands", tags=command_stats_tags)
+        return await super().invoke(ctx)
