@@ -32,13 +32,6 @@ class RedisConnection(object):
         address = modified_config.pop('host'), modified_config.pop('port')
         cls.pool = await aioredis.create_redis_pool(address, **modified_config)
 
-    async def __aenter__(self):
-        self.conn = self.pool
-        return self
-
-    async def __aexit__(self, exc_type, exc, tb):
-        pass
-
     @classmethod
     async def get_connection(cls):
         """
@@ -55,6 +48,14 @@ class RedisConnection(object):
 
         del self
 
+    async def __aenter__(self):
+        v = await self.get_connection()
+        self.conn = v.conn
+        return self
+
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.disconnect()
+
     async def publish_json(self, channel:str, json:dict) -> None:
         """
         Publishes some JSON to a given redis channel.
